"""
This module is flow360 for simulation based models
"""

from flow360.accounts_utils import Accounts
from flow360.component.case import Case
from flow360.component.project import Project
from flow360.component.simulation import services
from flow360.component.simulation import units as u
from flow360.component.simulation.entity_info import GeometryEntityInfo
from flow360.component.simulation.meshing_param.edge_params import (
    AngleBasedRefinement,
    AspectRatioBasedRefinement,
    HeightBasedRefinement,
    ProjectAnisoSpacing,
    SurfaceEdgeRefinement,
)
from flow360.component.simulation.meshing_param.face_params import (
    BoundaryLayer,
    PassiveSpacing,
    SurfaceRefinement,
)
from flow360.component.simulation.meshing_param.params import (
    MeshingDefaults,
    MeshingParams,
)
from flow360.component.simulation.meshing_param.volume_params import (
    AutomatedFarfield,
    AxisymmetricRefinement,
    RotationCylinder,
    UniformRefinement,
)
from flow360.component.simulation.models.material import Air, SolidMaterial, Sutherland
from flow360.component.simulation.models.solver_numerics import (
    HeatEquationSolver,
    KOmegaSST,
    KOmegaSSTModelConstants,
    LinearSolver,
    NavierStokesSolver,
    NoneSolver,
    SpalartAllmaras,
    SpalartAllmarasModelConstants,
    TransitionModelSolver,
)
from flow360.component.simulation.models.surface_models import (
    Freestream,
    HeatFlux,
    Inflow,
    Mach,
    MassFlowRate,
    Outflow,
    Periodic,
    Pressure,
    Rotational,
    SlipWall,
    SymmetryPlane,
    Temperature,
    TotalPressure,
    Translational,
    Wall,
)
from flow360.component.simulation.models.turbulence_quantities import (
    TurbulenceQuantities,
)
from flow360.component.simulation.models.volume_models import (
    ActuatorDisk,
    AngleExpression,
    AngularVelocity,
    BETDisk,
    BETDiskChord,
    BETDiskSectionalPolar,
    BETDiskTwist,
    Fluid,
    ForcePerArea,
    FromUserDefinedDynamics,
    HeatEquationInitialCondition,
    NavierStokesInitialCondition,
    PorousMedium,
    Rotation,
    Solid,
)
from flow360.component.simulation.operating_condition.operating_condition import (
    AerospaceCondition,
    GenericReferenceCondition,
    ThermalState,
    operating_condition_from_mach_reynolds,
)
from flow360.component.simulation.outputs.output_entities import (
    Isosurface,
    Point,
    PointArray,
    Slice,
)
from flow360.component.simulation.outputs.outputs import (
    AeroAcousticOutput,
    IsosurfaceOutput,
    ProbeOutput,
    SliceOutput,
    SurfaceIntegralOutput,
    SurfaceOutput,
    SurfaceProbeOutput,
    TimeAverageSliceOutput,
    TimeAverageSurfaceOutput,
    TimeAverageVolumeOutput,
    UserDefinedField,
    VolumeOutput,
)
from flow360.component.simulation.primitives import Box, Cylinder, ReferenceGeometry
from flow360.component.simulation.simulation_params import SimulationParams
from flow360.component.simulation.time_stepping.time_stepping import (
    AdaptiveCFL,
    RampCFL,
    Steady,
    Unsteady,
)
from flow360.component.simulation.unit_system import (
    SI_unit_system,
    imperial_unit_system,
)
from flow360.component.simulation.user_defined_dynamics.user_defined_dynamics import (
    UserDefinedDynamic,
)
from flow360.environment import Env
from flow360.version import __solver_version__, __version__

__all__ = [
    "Env",
    "Case",
    "AngleBasedRefinement",
    "AspectRatioBasedRefinement",
    "ProjectAnisoSpacing",
    "BoundaryLayer",
    "PassiveSpacing",
    "__solver_version__",
    "__version__",
    "Accounts",
    "Project",
    "u",
    "SimulationParams",
    "SI_unit_system",
    "imperial_unit_system",
    "services",
    "MeshingParams",
    "MeshingDefaults",
    "SurfaceRefinement",
    "AutomatedFarfield",
    "AxisymmetricRefinement",
    "RotationCylinder",
    "UniformRefinement",
    "SurfaceEdgeRefinement",
    "HeightBasedRefinement",
    "ReferenceGeometry",
    "Cylinder",
    "GeometryEntityInfo",
    "AerospaceCondition",
    "ThermalState",
    "Steady",
    "Unsteady",
    "RampCFL",
    "AdaptiveCFL",
    "Wall",
    "Freestream",
    "SlipWall",
    "Outflow",
    "Inflow",
    "Periodic",
    "SymmetryPlane",
    "Fluid",
    "Solid",
    "ActuatorDisk",
    "AngularVelocity",
    "BETDisk",
    "BETDiskChord",
    "BETDiskSectionalPolar",
    "BETDiskTwist",
    "Rotation",
    "PorousMedium",
    "SurfaceOutput",
    "TimeAverageSurfaceOutput",
    "VolumeOutput",
    "TimeAverageVolumeOutput",
    "SliceOutput",
    "TimeAverageSliceOutput",
    "IsosurfaceOutput",
    "SurfaceIntegralOutput",
    "ProbeOutput",
    "SurfaceProbeOutput",
    "AeroAcousticOutput",
    "HeatEquationSolver",
    "NavierStokesSolver",
    "NoneSolver",
    "SpalartAllmaras",
    "KOmegaSST",
    "SpalartAllmarasModelConstants",
    "KOmegaSSTModelConstants",
    "LinearSolver",
    "ForcePerArea",
    "Air",
    "Sutherland",
    "SolidMaterial",
    "Slice",
    "Isosurface",
    "TurbulenceQuantities",
    "UserDefinedDynamic",
    "Translational",
    "NavierStokesInitialCondition",
    "FromUserDefinedDynamics",
    "HeatEquationInitialCondition",
    "Temperature",
    "HeatFlux",
    "Point",
    "PointArray",
    "AngleExpression",
    "Box",
    "GenericReferenceCondition",
    "TransitionModelSolver",
    "Pressure",
    "TotalPressure",
    "Rotational",
    "Mach",
    "MassFlowRate",
    "UserDefinedField",
    "operating_condition_from_mach_reynolds",
]
